@@ -18,14 +18,17 @@
 #include <stdio.h>
 #include <stdarg.h>
 #include <sys/types.h>
+#include <string.h>
 #include "global.h"
 #include "dialog.h"
 #include "input.h"
 #include "color.h"
 #include "util.h"
 #include "win.h"
+#include "mouse.h"
+#include "main.h"
 
-static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/dialog.c,v 1.3 1994/06/27 22:52:51 miguel Exp $";
+static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/dialog.c,v 1.7 1994/08/10 21:17:54 miguel Exp $";
 static char buffer [4096];
 
 static Dialog *current_dialog = 0;
@@ -33,9 +36,24 @@ WINDOW *top_window;
 
 void (*refresh_fn)();
 
+/* Poor man's window puts, it doesn't handle auto-wrap */
+void my_wputs (WINDOW *w, int y, int x, char *text)
+{
+    char p;
+
+    wmove (w, y, x);
+    while ((p = *text++) != 0){
+	if (p == '\n')
+	    wmove (w, ++y, x);
+	else 
+	    waddch (w, p);
+    }
+}
+
 void create_dialog (int cols, int rows, char *header, char *text, int error)
 {
     int base = LINES/3;
+    int xpos, ypos;
     Dialog *newd;
     
     if (rows+1 > LINES/3+2)
@@ -44,10 +62,16 @@ void create_dialog (int cols, int rows, char *header, char *text, int error)
     newd = (Dialog *) xmalloc (sizeof (Dialog), "create_dialog");
     newd->backpointer = current_dialog;
     current_dialog = newd;
-    
-    newd->d = newwin (rows+4, cols+4, base-(rows+1)/2, COLS/2-(cols+5)/2);
+
+    xpos = COLS/2-(cols+5)/2;
+    ypos = base-(rows+1)/2;
+    newd->d = newwin (rows+4, cols+4, ypos, xpos);
     newd->f = derwin (newd->d, rows+2, cols+2, 1, 1);
     newd->t = derwin (newd->d, rows, cols, 2, 2);
+    
+    push_event (1, 1, COLS, LINES, (mouse_h) null_event, 0);
+    push_frame (xpos, ypos, 0);
+    
     leaveok (newd->d, TRUE);
     leaveok (newd->f, TRUE);
     leaveok (newd->t, TRUE);
@@ -64,8 +88,8 @@ void create_dialog (int cols, int rows, char *header, char *text, int error)
     }
     box (newd->f, ACS_VLINE, ACS_HLINE);
     mvwprintw (newd->f, 0, (cols-strlen (header)-2)/2, header);
-    wclr (newd->t); 
-    mvwprintw (newd->t, 0, 0, text); 
+    wclr (newd->t);
+    my_wputs (newd->t, 0, 0, text); 
     touchwin (newd->t);
     touchwin (newd->f);
     touchwin (newd->d);
@@ -82,13 +106,15 @@ WINDOW *get_top_text ()
 int run_dialog ()
 {
     int key;
-    
-    key = getch ();
+
+    push_event (1, 1, COLS, LINES, click_may_break_loop, quit_event);
+    key = mi_getch ();
+    pop_event ();
     refresh_screen ();
     return key;
 }
 
-void done_dialog ()
+void destroy_dialog ()
 {
     Dialog *p;
     
@@ -106,6 +132,8 @@ void done_dialog ()
     else
 	top_window = 0;
     free (p);
+    pop_frame ();
+    pop_event ();
 }
 
 int message (int error, char *header, char *text,  ...)
@@ -126,7 +154,7 @@ int message (int error, char *header, char *text,  ...)
     create_dialog (len, lines, header, buf, error);
     if (!(error & D_INSERT)){
 	v = run_dialog ();
-	done_dialog ();
+	destroy_dialog ();
 	return v;
     }
     return 0; 
@@ -150,7 +178,7 @@ int error (int status, int errnum, char *text,  ...)
     len = max (strlen (header), msglen (buf, &lines));
     create_dialog (len, lines, header, buf, 1);
     v = run_dialog ();
-    done_dialog ();
+    destroy_dialog ();
     va_end (args);
     return 0;
 }
@@ -159,7 +187,7 @@ char *input_dialog (char *header, char *text, char *def_text)
 {
     int    len, lines;
     char   *return_value;
-    Input  in;
+    Input  *in;
     int    c;
 
     strcpy (buffer, text);
@@ -167,20 +195,18 @@ char *input_dialog (char *header, char *text, char *def_text)
     len = max (strlen (header), msglen (buffer, &lines));
     len = max (len, 60);
     create_dialog (len, lines+1, header, buffer, 0);
-    create_input (&in, 1, lines, current_dialog->t, INPUT_COLOR,
-		  58, def_text);
-
-    return_value = in.buffer;
+    in = create_input (1, lines, current_dialog->t, INPUT_COLOR, 58, def_text);
+    return_value = in->buffer;
     while ((c = mi_getch ()) != '\n'){
 	if (c == '\e'){
 	    return_value = 0;
-	    free (in.buffer);
 	    break;
 	}
-	handle_char (&in, c);
+	handle_char (in, c);
     }
-    done_dialog ();
+    destroy_dialog ();
     (*refresh_fn)();
+    destroy_input (in, IN_KEEP_BUFFER); 
     return (return_value);
 }
 
