@@ -1,5 +1,5 @@
-
-#define MAXFILES 1024
+#define MIN_FILES 128
+#define RESIZE_STEPS 128
 
 typedef struct {
 
@@ -16,13 +16,16 @@ typedef struct {
     } f;
 } file_entry;
 
-typedef file_entry dir_list [MAXFILES];
+typedef struct {
+    file_entry *list;
+    int         size;
+} dir_list;
 
 typedef int sortfn (const void *, const void*);
-int do_load_dir (dir_list *list, sortfn *sort);
-void do_sort (dir_list *list, sortfn *sort, int top);
+int do_load_dir (dir_list *list, sortfn *sort, int reverse);
+void do_sort (dir_list *list, sortfn *sort, int top, int reverse);
 dir_list *do_collect_stat (dir_list *dir, int top);
-int do_reload_dir (dir_list *list, sortfn *sort, int count);
+int do_reload_dir (dir_list *list, sortfn *sort, int count, int reverse);
 void clean_dir (dir_list *list, int count);
 
 /* Sorting functions */
