@@ -60,7 +60,7 @@ void regex_command (char *filename)
     int  col;
     int  file_len = strlen (filename);
 
-    sprintf (buffer, "%s/.nc.ext", home_dir);
+    sprintf (buffer, "%s/.mc.ext", home_dir);
     if (exist_file (buffer))
 	extension_file = buffer;
     else
