@@ -38,9 +38,9 @@
 #include "find.h"
 #include "color.h"
 
-static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/find.c,v 1.3 1994/06/27 22:53:03 miguel Exp $";
+static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/find.c,v 1.7 1994/09/08 19:28:02 miguel Exp $";
 
-static Input in;           /* Asks the file to search           */
+static Input *in;          /* Asks the file to search           */
 static WINDOW *text_win;   /* Contains the Menu and Text        */
 static WINDOW *file_win;   /* Contains the files found          */
 static find_list *list;    /* double-linked list of files found */
@@ -55,7 +55,7 @@ extern Panel *current_panel; /* current_panel (see main.c for details) */
 extern int mi_getch();       /* Alternate routine  (see key.c for details) */
 extern void select_item();   /* See main.c for details */
 extern void paint_dir();     /* See screen.c for details */
-extern void done_dialog();   /* See dialog.c for details */
+extern void destroy_dialog();   /* See dialog.c for details */
 extern void wclr();			
 /* Stack */
 
@@ -88,17 +88,19 @@ static char *pop_s()
 static char *input_find (char *def_text)
 {
     int    c;
-
-    create_input (&in, 1, 3, text_win, INPUT_COLOR, MAX_FIND_COLS,
-		  def_text);
+    char   *val;
+    
+    in = create_input (1, 3, text_win, INPUT_COLOR, MAX_FIND_COLS, def_text);
 
     while ((c = mi_getch ()) != '\n'){
 	if (c == '\e')
 	    return 0;
-	handle_char (&in, c);
+	handle_char (in, c);
     }
     wattrset (text_win, REVERSE_COLOR);
-    return (in.buffer);
+    val = in->buffer;
+    destroy_input (in, IN_KEEP_BUFFER);
+    return (val);
 }
 
 static void create_find_dialog()
@@ -316,7 +318,9 @@ static int select_and_change_panel()
     if (chdir (list-> path) == -1)
 	return 0;
     clean_dir (&current_panel->dir, current_panel->count);
-    current_panel->count = do_load_dir (&current_panel->dir, 					current_panel->sort_type);
+    current_panel->count = do_load_dir (&current_panel->dir,
+ 					current_panel->sort_type,
+					current_panel->reverse);
     current_panel->top_file = 0;
     current_panel->selected = 0;
     current_panel->marked = 0;
@@ -326,7 +330,7 @@ static int select_and_change_panel()
     paint_panel (current_panel);
     
     if (!list->isdir){
-	for (i = 0; strcmp (list->fname, current_panel->dir[i].fname); i++)
+	for (i=0; strcmp (list->fname, current_panel->dir.list[i].fname); i++)
 	    ;
 	current_panel->selected = i; 
 	current_panel->top_file = i;
@@ -508,7 +512,7 @@ static void find_dialog ()
     }
     nodelay (stdscr, FALSE);
     destroy_list ();
-    done_dialog ();
+    destroy_dialog ();
 }
 
 void do_find ()
