@@ -1,4 +1,3 @@
-#define ALT_W ('w'|128)
 extern char *home_dir;
 
 #define min(x,y) (x>y ? y: x)
@@ -7,3 +6,6 @@ extern char *home_dir;
 void repaint_screen ();
 void refresh_screen ();
 
+#ifdef ultrix
+char *strdup (char *);
+#endif
