@@ -21,18 +21,20 @@
 #include "color.h"
 #include "dialog.h"
 #include "util.h"
+#include "input.h"
 #include "win.h"
 
 #define MAXLINKNAME 80
 #define HISTORY_SIZE 20
 
-static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/help.c,v 1.5 1994/06/27 22:53:05 miguel Exp $";
+static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/help.c,v 1.8 1994/07/27 03:57:42 miguel Exp $";
 static char *data;
 static int help_lines = 18;
 WINDOW *whelp;
 static char *history [HISTORY_SIZE];
 static int  history_ptr;
 static char *main;
+static char *last_shown = 0;
 
 char *search_string (char *start, char *text)
 {
@@ -168,6 +170,7 @@ static void show (char *paint_start, char *selected_start)
 	    col++;
 	}
     }
+    last_shown = p;
     wrefresh (whelp);
 }
 
@@ -176,18 +179,23 @@ void interactive_display (char *filename)
     int quit = 0;
     char *current, *start, *selected_item;
     
-    if ((data = load_file (filename)) == 0)
+    if ((data = load_file (filename)) == 0){
+	message (1, " Error ", " Can't open file %s ", filename);
 	return;
-    create_dialog (60, help_lines, " Main ", "", 0);
-    whelp = get_top_text ();
+    }
     if (!(main = search_string (data, "[main]"))){
 	message (1, " Error ", " Can't find main node in help file ");
 	return;
     }
+    create_dialog (60, help_lines, " Main ", "", 0);
+    whelp = get_top_text ();
+    
     selected_item = search_string_node (main, "\001") - 1;
     current = start = main;
+    
     for (history_ptr = 0; history_ptr < HISTORY_SIZE; history_ptr++)
 	history [history_ptr] = current;
+    
     do {
 	show (current, selected_item);
 	switch (mi_getch ()){
@@ -196,18 +204,20 @@ void interactive_display (char *filename)
 	    break;
 
 	case KEY_BACKSPACE:
+	case KEY_PPAGE:
 	case 0177:
 	case 8:
 	    current = move_backward (current, help_lines-1);
 	    break;
 
-	case 22:		/* C-v like emacs */
-	case 6:			/* C-f */
+	case XCTRL('v'):	/* C-v like emacs */
+	case KEY_NPAGE:
+	case XCTRL('f'):	/* C-f */
 	case KEY_DOWN:
 	    current = move_forward (current, 2);
 	    break;
 
-	case 2:			/* C-b */
+	case XCTRL('b'):	/* C-b */
 	case KEY_UP:
 	    current = move_backward (current, 2);
 	    break;
@@ -232,12 +242,20 @@ void interactive_display (char *filename)
 	    selected_item = select_next_link (start, selected_item);
 	    if (!selected_item)
 		selected_item = main;
+	    else {
+		if (selected_item >= last_shown ||
+		    selected_item < current){
+		    current = selected_item;
+		}
+	    }
 	    break;
 
+	case KEY_F(10):
 	case '\e':
 	    quit = 1;
 	}
     } while (!quit);
     free (data);
+    destroy_dialog ();
     refresh_screen ();
 }
