@@ -1,13 +1,14 @@
-
 enum { view_brief, view_full, view_long, view_info, view_nothing };
 enum { show_dates, show_perm };
 enum { brief_mode, full_mode, long_mode };
 
 typedef struct {
     dir_list dir;		/* Directory contents */
+    
     int      view_type;		/* type of view */
     int      active;		/* If panel is currently selected */
     char     cwd [MAXPATHLEN];	/* Current Working Directory */
+    char     lwd [MAXPATHLEN];	/* Last Working Directory */
     int      count;		/* Number of files in dir structure */
     int      lines;		/* Panel Lines */
     int      cols;		/* Panel columns */
@@ -16,6 +17,7 @@ typedef struct {
     int      top_file;		/* The file showed on the top of the panel */
     int      selected;		/* Index to the selected file */
     int      is_status;		/* Is the panel a status display? */
+    int      reverse;		/* Show listing in reverse? */
     sortfn   *sort_type;	/* Sort type */
     WINDOW   *win_file;		/* Where the files are listed */
     WINDOW   *win_mini;		/* The mini-info */
@@ -48,8 +50,11 @@ extern int fast_reload;
 			 p->view_type == view_long)
 
 #define VIEW_DISABLED 0x80
+
+#define RP_ONLY_PAINT 0
+#define RP_SETPOS 1
 void set_colors (Panel *panel);
-void repaint_file (Panel *panel, int file_index);
+void repaint_file (Panel *panel, int file_index, int set_pos);
 void display_mini_info (Panel *panel);
 void panel_reload (Panel *panel);
 void paint_dir (Panel *panel);
