@@ -25,7 +25,7 @@
 #include "util.h"
 #include "color.h"
 
-static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/screen.c,v 1.6 1994/06/27 23:49:05 miguel Exp $";
+static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/screen.c,v 1.13 1994/09/08 19:28:26 miguel Exp $";
 
 int show_mini_info = 1;		/* Show miniinfo */
 
@@ -69,17 +69,20 @@ void set_attr (Panel *panel, int hilight, int marked)
 }
 
 /* Use current attributes to update the contents of the file */
-void repaint_file (Panel *panel, int file_index)
+void repaint_file (Panel *panel, int file_index, int set_pos)
 {
     int c = ' ';
     int isdir = 0;
     int column;
-    
-#define entry (panel->dir [file_index].buf)
+    char *sdir_txt;
+
+#define entry (panel->dir.list [file_index].buf)
     
     if (S_ISDIR (entry.st_mode)){
 	isdir = 1;
 	c = '/';
+	sdir_txt = strcmp (panel->dir.list [file_index].fname, "..")
+	    ? ">SUB-DIR<" : ">UP--DIR<";
     } else if (S_ISLNK (entry.st_mode))
 	c = '@';
     else if (S_ISSOCK (entry.st_mode) || S_ISFIFO (entry.st_mode))
@@ -90,11 +93,12 @@ void repaint_file (Panel *panel, int file_index)
     switch (panel->view_type){
     case view_brief:
 	column = (file_index - panel->top_file) / panel->lines;
-	wmove (panel->win_file,
-	       (file_index - panel->top_file) % panel->lines + 2,
-	       (column * (COLS/4-1) + 1));
+	if (set_pos)
+	    wmove (panel->win_file,
+		   (file_index - panel->top_file) % panel->lines + 2,
+		   (column * (COLS/4-1) + 1));
 	wprintw (panel->win_file, "%c%-*s", c, COLS/4-3,
-		 name_trunc (panel->dir [file_index].fname, COLS/4-3));
+		 name_trunc (panel->dir.list [file_index].fname, COLS/4-3));
 	if (column)
 	    waddch (panel->win_file, ' ');
 	else
@@ -103,7 +107,8 @@ void repaint_file (Panel *panel, int file_index)
 
     case view_long:
 	/* Only here temporarily */
-	wmove (panel->win_file, file_index - panel->top_file + 2, 1);
+	if (set_pos)
+	    wmove (panel->win_file, file_index - panel->top_file + 2, 1);
 	wprintw (panel->win_file,
 		 "%10s %3d %8s %8s %11s %12s %-*s",
 		 string_perm (entry.st_mode),
@@ -111,22 +116,24 @@ void repaint_file (Panel *panel, int file_index)
 		 get_owner (entry.st_uid),
 		 get_group (entry.st_gid),
 		 size_trunc (entry.st_size),
-		 file_date (entry.st_ctime),
+		 file_date (entry.st_mtime),
 		 COLS-60,
-		 name_trunc (panel->dir [file_index].fname, COLS-60)
+		 name_trunc (panel->dir.list [file_index].fname, COLS-60)
 		 );
 
 	break;
 	
 	
     case view_full:
-	wmove (panel->win_file, file_index - panel->top_file + 2, 1);
+	if (set_pos)
+	    wmove (panel->win_file, file_index - panel->top_file + 2, 1);
 	wprintw (panel->win_file, 
 		   "%c%-*s", c, COLS/2-24, split_extension
-		 (name_trunc (panel->dir [file_index].fname, COLS/2-24), COLS/2-24));
+		 (name_trunc (panel->dir.list [file_index].fname, COLS/2-24),
+		  COLS/2-24));
 	waddch (panel->win_file, ACS_VLINE);
 	wprintw (panel->win_file, "%9s",
-		 isdir ? ">SUB-DIR<" : size_trunc (entry.st_size));
+		 isdir ? sdir_txt : size_trunc (entry.st_size));
 	waddch (panel->win_file, ACS_VLINE);
 
 	switch (extra_info){
@@ -135,10 +142,11 @@ void repaint_file (Panel *panel, int file_index)
 	    break;
 
 	case show_dates:
-	    wprintw (panel->win_file, "%12s", file_date_pck (entry.st_ctime));
+	    wprintw (panel->win_file, "%12s", file_date_pck (entry.st_mtime));
 	    break;
 	}
     }
+    wrefresh (panel->win_file);
 #undef stat
 }
 
@@ -177,11 +185,18 @@ void display_mini_info (Panel *panel)
 	if (panel->marked){
 	    wattrset (panel->win_file, MARKED_COLOR | A_BOLD);
 	    wprintw (panel->win_file, "  %s bytes in %d files",
-		     size_trunc (panel->total), panel->marked);
+		     size_trunc_sep (panel->total), panel->marked);
 	} else {
 	    set_colors (panel);
-	    wprintw(panel->win_file,"%-*s", panel->cols,
-		    name_trunc(panel->dir [panel->selected].fname, COLS/2-2));
+	    if (panel->view_type == view_brief){
+		/* You don't see this */
+		panel->view_type = view_full;
+		repaint_file (panel, panel->selected, RP_ONLY_PAINT);
+		panel->view_type = view_brief;
+	    } else
+		wprintw(panel->win_file,"%-*s", panel->cols,
+			name_trunc(panel->dir.list [panel->selected].fname,
+				   COLS/2-2));
 	}
     }
 }
@@ -205,9 +220,9 @@ void paint_dir (Panel *panel)
 	    empty_entry (panel, i+panel->top_file);
 	} else {
 	    hilight = panel->selected==i+panel->top_file && panel->active;
-	    marked  = panel->dir [i+panel->top_file].f.marked;
+	    marked  = panel->dir.list [i+panel->top_file].f.marked;
 	    set_attr (panel, hilight, marked);
-	    repaint_file (panel, i+panel->top_file);
+	    repaint_file (panel, i+panel->top_file, RP_SETPOS);
 	}
     }
     wstandend (panel->win_file);
@@ -345,7 +360,7 @@ void Xtry_to_select (Panel *panel, char *name)
     
     /* Search that subdirectory, if found select it */
     for (i = 0; i < panel->count; i++){
-	if (strcmp (subdir, panel->dir [i].fname))
+	if (strcmp (subdir, panel->dir.list [i].fname))
 	    continue;
 
 	if (i != panel->selected){
@@ -371,10 +386,11 @@ void Xtry_to_select (Panel *panel, char *name)
 #endif
 }
 
+/* Assumes that panel comes with sort_type and view_type already set */
 void init_panel (Panel *panel, int x1, int y1, int x2, int y2)
 {
     getwd (panel->cwd);
-    panel->sort_type = (sortfn *) sort_name;
+    strcpy (panel->lwd, ".");
     panel->win_file = newwin (y2 - y1, x2 - x1, y1, x1);
     panel->small_frame = panel->win_file;
     panel->big_frame   = newwin (y2 - y1, COLS, 0, 0); 
@@ -383,15 +399,33 @@ void init_panel (Panel *panel, int x1, int y1, int x2, int y2)
     wclr (panel->small_frame);
 /*    wclr (panel->big_frame);  */
 
+    panel->dir.list = (file_entry *) malloc (MIN_FILES * sizeof (file_entry));
+    panel->dir.size = MIN_FILES;
     panel->lines = y2-y1-3-(show_mini_info*2);
     panel->cols  = x2-x1-2;
-    panel->view_type = view_full;
     panel->top_file = 0;
     panel->selected = 0;
     panel->is_status = 0;
     panel->marked = 0;
     panel->total = 0;
-    full_frame (panel);
+    panel->reverse = 0;
+    
+#ifdef OLD_SETUP
+    panel->sort_type = (sortfn *) sort_name;
+    panel->view_type = view_full;
+#endif
+    
+    switch (panel->view_type){
+    case view_full:
+	full_frame (panel);
+	break;
+    case view_brief:
+	brief_frame (panel);
+	break;
+    case view_long:
+	long_frame (panel);
+	break;
+    }
 
     /* Configure repaint mode for the panel */
     leaveok (panel->win_file, TRUE);
@@ -412,13 +446,14 @@ void panel_reload (Panel *panel)
 	    return;
     }
     chdir (panel->cwd);
-    panel->count = do_reload_dir (&panel->dir, panel->sort_type, panel->count);
+    panel->count = do_reload_dir (&panel->dir, panel->sort_type, panel->count,
+				  panel->reverse);
     panel->marked = 0;
     panel->total  = 0;
     for (i = 0; i < panel->count; i++)
-	if (panel->dir [i].f.marked){
+	if (panel->dir.list [i].f.marked){
 	    panel->marked++;
-	    panel->total += panel->dir [i].buf.st_size;
+	    panel->total += panel->dir.list [i].buf.st_size;
 	}
     display_mini_info (panel);
 }
