@@ -31,7 +31,7 @@
 #include "main.h"
 #include "user.h"
 
-static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/user.c,v 1.6 1994/06/27 22:53:27 miguel Exp $";
+static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/user.c,v 1.9 1994/09/08 19:28:28 miguel Exp $";
 
 #define MAX_ENTRIES 40
 #define MAX_ENTRY_LEN 60
@@ -84,7 +84,7 @@ char *expand_format (char c)
     c |= 0x20;
     
     switch (c){
-    case 'f': return panel->dir [panel->selected].fname;
+    case 'f': return panel->dir.list [panel->selected].fname;
     case 'd': return panel->cwd;
     }
     return "";
@@ -140,7 +140,7 @@ void menu_input_loop (int top)
     int c;
     int i;
     
-    while ((c = getch ()) != '\e'){
+    while ((c = mi_getch ()) != '\e'){
 	switch (c){
 	case XCTRL('c'):
 	    return;
@@ -186,18 +186,19 @@ void user_menu_cmd ()
     char *menu, *p;
     int  col, i;
 
-    if (exist_file ("./nc.menu"))
-	menu = "./nc.menu";
+    if (exist_file ("./mc.menu"))
+	menu = "./mc.menu";
     else {
-	sprintf (buffer, "%s/.nc.menu", home_dir);
+	sprintf (buffer, "%s/.mc.menu", home_dir);
 	if (exist_file (buffer))
 	    menu = buffer;
 	else
 	    menu = MENU;
     }
-    if ((data = load_file (menu)) == NULL)
+    if ((data = load_file (menu)) == NULL){
+	message (1, " Error ", " Can't open file %s ", menu);
 	return;
-
+    }
     max_cols = 0;
     for (i = 0; i < MAX_ENTRIES; i++)
 	entries [i] = 0;
@@ -225,7 +226,7 @@ void user_menu_cmd ()
 
     paint_user_menu ();
     menu_input_loop (menu_lines);
-    done_dialog ();
+    destroy_dialog ();
     refresh_screen ();
     free (data);
 }
