@@ -2,11 +2,14 @@ int msglen (char *text, int *lines);
 char *trim (char *s, char *d, int len);
 char *name_trunc (char *txt, int trunc_len);
 char *size_trunc (long int size);
+char *size_trunc_sep (long int size);
 int is_exe (mode_t mode);
 char *string_perm (mode_t mode_bits);
 char *strip_home(char *dir);
 char *extension (char *);
 char *split_extension (char *, int pad);
+char *get_full_name (char *dir, char *file);
+
 extern int easy_patterns;
 extern int align_extensions;
 void *xmalloc (int, char *);
@@ -34,3 +37,4 @@ int regexp_match (char *pattern, char *string);
 
 int my_system (char *shell, char *command);
 void save_stop_handler ();
+void init_uid_gid_cache ();
