@@ -17,8 +17,9 @@
 #include <ncurses.h>
 #include "win.h"
 #include "color.h"
+#include "mouse.h"
 
-static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/win.c,v 1.2 1994/06/27 22:53:35 miguel Exp $";
+static char rcsid [] = "$Header: /usr/users/miguel/c/CVS/nc/win.c,v 1.4 1994/07/27 03:58:15 miguel Exp $";
 
 void wclr (WINDOW *w)
 {
@@ -31,13 +32,32 @@ void wclr (WINDOW *w)
     }
 }
 
-void define_label (WINDOW *fkeys, int index, char *text)
+void define_label (WINDOW *fkeys, int index, char *text, void (*cback)())
 {
     wprintw (fkeys, "%d", index);
     wattron (fkeys, SELECTED_COLOR);
     wprintw (fkeys, "%-6s", text);
     wstandend (fkeys);
     waddch (fkeys, ' ');
+#ifdef use_mouse
+    if (cback)
+	push_event ((index-1)*8, LINES, (index*8)-1, LINES,click,(void*)cback);
+#endif
+}
+
+void define_label_quit (WINDOW *fkeys, int index, char *text, int (*cback)())
+{
+    wprintw (fkeys, "%d", index);
+    wattron (fkeys, SELECTED_COLOR);
+    wprintw (fkeys, "%-6s", text);
+    wstandend (fkeys);
+    waddch (fkeys, ' ');
+#ifdef use_mouse
+    if (cback){
+	push_event ((index-1)*8, LINES, (index*8)-1, LINES,
+		    click_may_break_loop, (void *) cback);
+    }
+#endif
 }
 
 WINDOW *new_fkey ()
